@@ -1,6 +1,7 @@
 from typing import Callable
 import pygame
 
+import pygame_widgets
 from pygame_widgets.widget import WidgetBase
 
 
@@ -18,6 +19,8 @@ class ProgressBar(WidgetBase):
 
         self.radius = self._height / 2 if self.curved else 0
 
+        self.disable()
+
     def listen(self, events):
         pass
 
@@ -74,6 +77,5 @@ if __name__ == '__main__':
 
         win.fill((255, 255, 255))
 
-        progressBar.draw()
-
+        pygame_widgets.update(events)
         pygame.display.update()
