@@ -1,8 +1,12 @@
 from abc import abstractmethod, ABC
 
+from pygame.event import Event
+
+from pygame_widgets.mouse import Mouse
+
 
 class WidgetBase(ABC):
-    def __init__(self, win, x, y, width, height):
+    def __init__(self, win, x, y, width, height, isSubWidget=False):
         """ Base for all widgets
 
         :param win: Surface on which to draw
@@ -21,8 +25,13 @@ class WidgetBase(ABC):
         self._y = y
         self._width = width
         self._height = height
+        self._isSubWidget = isSubWidget
 
         self._hidden = False
+        self._disabled = False
+
+        if not isSubWidget:
+            WidgetHandler.addWidget(self)
 
     @abstractmethod
     def listen(self, events):
@@ -33,7 +42,7 @@ class WidgetBase(ABC):
         pass
 
     def contains(self, x, y):
-        return (self._x < x - self.win.get_abs_offset()[0] < self._x + self._width) and\
+        return (self._x < x - self.win.get_abs_offset()[0] < self._x + self._width) and \
                (self._y < y - self.win.get_abs_offset()[1] < self._y + self._height)
 
     def hide(self):
@@ -41,6 +50,20 @@ class WidgetBase(ABC):
 
     def show(self):
         self._hidden = False
+        if not self._isSubWidget:
+            WidgetHandler.moveToTop(self)
+
+    def disable(self):
+        self._disabled = True
+
+    def enable(self):
+        self._disabled = False
+
+    def isSubWidget(self):
+        return self._isSubWidget
+
+    def moveToTop(self):
+        WidgetHandler.moveToTop(self)
 
     def moveX(self, x):
         self._x += x
@@ -107,3 +130,35 @@ class WidgetBase(ABC):
 
     def setHeight(self, height):
         self._height = height
+
+
+class WidgetHandler:
+    _widgets: [WidgetBase] = []
+
+    @staticmethod
+    def main(events: [Event]) -> None:
+        blocked = False
+
+        for widget in WidgetHandler._widgets[::-1]:
+            if not blocked or not widget.contains(*Mouse.getMousePos()):
+                widget.listen(events)
+
+            # Ensure widgets covered by others are not affected (widgets created later)
+            if widget.contains(*Mouse.getMousePos()):  # TODO: Unless 'transparent'
+                blocked = True
+
+        for widget in WidgetHandler._widgets:
+            widget.draw()
+
+    @staticmethod
+    def addWidget(widget: WidgetBase) -> None:
+        WidgetHandler._widgets.append(widget)
+
+    @staticmethod
+    def moveToTop(widget: WidgetBase):
+        WidgetHandler._widgets.remove(widget)
+        WidgetHandler.addWidget(widget)
+
+    @staticmethod
+    def getWidgets() -> [WidgetBase]:
+        return WidgetHandler._widgets
